Structs
- Error when decoding an encoded bit vector into a game, because the bit vector is invalid.
- Error when encoding a chess game.
- An encoder that lets you add moves one-by-one, rather than a whole game at once.
Enums
- Kind of error when encoding a chess game.
Traits
- A trait for decoding games move-by-move.
Functions
- Decodes a bit vector into a game, returning both a vector of all moves and all positions. The N’th position in the position vector is the position after the N’th move in the move vector.
- Decodes a bit vector into a game, calling an implementation of the
MoveByMoveDecodertrait for each move. This allows for more fine-grained processing thandecode_game. - Encodes a chess game into a compressed bit vector.
- Encodes a chess game, represented as a PGN (Portable Game Notation), into a compressed bit vector.
- Encodes a chess game, stored in a PGN file, into a compressed bit vector.
Type Aliases
- The result of a decoding operation.
- The result of an encoding operation.